@@ -1,6 +1,6 @@
 // MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 //
-//  $Id: common.h 131 2007-06-09 16:18:15Z taku-ku $;
+//  $Id: common.h 177 2009-05-31 03:16:43Z taku-ku $;
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
@@ -15,7 +15,11 @@
 #include <iostream>
 #include <algorithm>
 #include <cmath>
-#include <strstream>
+#include <sstream>
+
+#ifdef __CYGWIN__
+#define _GLIBCXX_EXPORT_TEMPLATE
+#endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -27,10 +31,11 @@
 /* why windows.h define such a generic macro */
 #undef max
 #undef min
+#define snprintf _snprintf
 #endif
 
 #define COPYRIGHT "MeCab: Yet Another Part-of-Speech and Morphological Analyzer\n\
-\nCopyright(C) 2001-2007 Taku Kudo \nCopyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation\n"
+\nCopyright(C) 2001-2009 Taku Kudo \nCopyright(C) 2004-2008 Nippon Telegraph and Telephone Corporation\n"
 
 #define SYS_DIC_FILE            "sys.dic"
 #define UNK_DEF_FILE            "unk.def"
@@ -99,10 +104,11 @@ namespace MeCab {
   };
 
   struct whatlog {
-    std::ostrstream stream_;
+    std::ostringstream stream_;
+    std::string str_;     
     const char *str() {
-      stream_ << std::ends;
-      return stream_.str();
+      str_ = stream_.str();
+      return str_.c_str();
     }
     jmp_buf cond_;
   };
@@ -119,7 +125,7 @@ namespace MeCab {
 #define WHAT what_.stream_
 
 #define CHECK_RETURN(condition, value) \
-if (!(condition)) \
+if (condition) {} else \
   if (setjmp(what_.cond_) == 1) { \
     return value;  \
   } else \
@@ -130,7 +136,7 @@ if (!(condition)) \
 #define CHECK_FALSE(condition)  CHECK_RETURN(condition, false)
 
 #define CHECK_CLOSE_FALSE(condition) \
-if (!(condition)) \
+if (condition) {} else \
   if (setjmp(what_.cond_) == 1) { \
     close(); \
     return false;  \
